****************************
The sherpa.astro.data module
****************************

.. currentmodule:: sherpa.astro.data

.. automodule:: sherpa.astro.data

   .. rubric:: Classes

   .. autosummary::
      :toctree: api

      DataOgipResponse
      DataARF
      DataRMF
      DataRosatRMF
      DataPHA
      DataIMG
      DataIMGInt

Class Inheritance Diagram
=========================

.. inheritance-diagram:: DataOgipResponse DataARF DataRMF DataRosatRMF DataPHA DataIMG DataIMGInt
   :parts: 1
